<?php

namespace Modules\Pp\Http\Controllers;

use DateInterval;
use DatePeriod;
use DateTime;
use Exception;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\DB;
use Modules\Hr\Entities\EmployeeSite;
use Modules\Hr\Entities\Company;
use Modules\Pp\Entities\Machinary;

class ProductionReportController extends Controller
{

    public function allCompanies()
    {
        try {

            $companies = EmployeeSite::all();
            return response()->json(["companies" => $companies]);
        } catch (Exception $ex) {
            return response()->json(["error" => $ex]);
        }
    }


    public function allMachineries($site_id)
    {
        try {

            $machineries = Machinary::where('site_id', '=', $site_id)->get();
            return response()->json(["machine" => $machineries]);
        } catch (Exception $ex) {
            return response()->json(["error" => $ex]);
        }
    }



    public function createProductionPlanReport($factory, $machine, $date_from, $date_to)
    {
        $machinery_result = Machinary::all();

        $factory_filter = "";
        if ($factory != "null") {
            $factory_filter = " AND pp_machinery.site_id  = '" . $factory . "' ";
            $machinery_result = Machinary::where('site_id', '=', $factory)->get();
        }


        $machine_filter = "";
        if ($machine != "null") {
            $machine_filter = " AND pp_machinery_plans.machinery_id = '" . $machine . "' ";
            $machinery_result = Machinary::where('machinery_id', '=', $machine)->get();
        }

        $query = 'SELECT DISTINCT pp_machinery.machinery_no,
        pp_customer_orders.factory_po_num,
        pp_machinery_plans.date,
        st_products.size,
        pp_machinery_plans.quantity,
        "" AS farm,
        st_countries.country_name,
        "" AS other,
        hr_att_shifts.remark AS shift FROM pp_machinery_plans
        INNER JOIN hr_att_shifts ON pp_machinery_plans.shift_id = hr_att_shifts.shift_id
        INNER JOIN pp_customer_order_plans_data ON pp_machinery_plans.customer_order_plan_data_id = pp_customer_order_plans_data.customer_order_plan_data_id
        INNER JOIN pp_customer_order_plans ON pp_customer_order_plans_data.customer_order_plan_id = pp_customer_order_plans.customer_order_plan_id
        INNER JOIN pp_customer_orders ON pp_customer_order_plans.order_id = pp_customer_orders.order_id
        LEFT JOIN st_products ON pp_customer_order_plans_data.product_id = st_products.product_id
        INNER JOIN st_countries ON pp_customer_orders.country_id = st_countries.country_id
        INNER JOIN pp_machinery ON pp_machinery_plans.machinery_id = pp_machinery.machinery_id
        WHERE pp_machinery_plans.date BETWEEN "' . $date_from . '" AND "' . $date_to . '" ' . $machine_filter . ' ' . $factory_filter . ' ORDER BY pp_machinery_plans.date';

        $date_query = "SELECT LAST_DAY('" . $date_to . "') AS end_date";
        $date_to = DB::select($date_query)[0]->end_date;


        $date_array = [];
        $startDate = new DateTime($date_from);
        $endDate = new DateTime($date_to);
        $endDate->modify('+1 day'); // Include the end date in the loop

        $interval = new DateInterval('P1D'); // 1 day interval
        $dateRange = new DatePeriod($startDate, $interval, $endDate);
        foreach ($dateRange as $date) {
            $date_array[] = $date->format('d-M');
        }






        $result = DB::select($query);
        $machinery_array = [];

        foreach ($machinery_result as $machine_res) {
            $day_po_array = [];
            $day_size_array = [];
            $day_plan_array = [];
            $day_farm_array = [];
            $day_country_array = [];
            $day_other_array = [];

            $night_po_array = [];
            $night_size_array = [];
            $night_plan_array = [];
            $night_farm_array = [];
            $night_country_array = [];
            $night_other_array = [];
            foreach ($result as $data) {
                if ($machine_res->machinery_no == $data->machinery_no && $data->shift == "day") {
                    $day_po_array[] = $data->factory_po_num;
                    $day_size_array[] = $data->size;
                    $day_plan_array[] = $data->quantity;
                    $day_farm_array[] = $data->farm;
                    $day_country_array[] = $data->country_name;
                    $day_other_array[] = $data->other;
                } else if ($machine_res->machinery_no == $data->machinery_no && $data->shift == "night") {
                    $night_po_array[] = $data->factory_po_num;
                    $night_size_array[] = $data->size;
                    $night_plan_array[] = $data->quantity;
                    $night_farm_array[] = $data->farm;
                    $night_country_array[] = $data->country_name;
                    $night_other_array[] = $data->other;
                }
            }



            $machinery_array[] = [
                "machine" => $machine_res->machinery_no,
                "day" => [
                    "date" => $date_array,
                    "po" => $day_po_array,
                    "size" => $day_size_array,
                    "plan_qty" => $day_plan_array,
                    "farm" => $day_farm_array,
                    "country" => $day_country_array,
                    "other" => $day_other_array,
                ],
                "night" => [
                    "date" => $date_array,
                    "po" => $night_po_array,
                    "size" => $night_size_array,
                    "plan_qty" => $night_plan_array,
                    "farm" => $night_farm_array,
                    "country" => $night_country_array,
                    "other" => $night_other_array,
                ]
            ];
        }

        $title = "Production Plan Report";
        $machineries = [];
        foreach ($machinery_array as $machinery) {
            $machine = [];
            array_push($machine, $machinery);
            array_push($machineries, $machine);
        }
        return view('pp::production_plan_report')->with(compact('title', 'machineries'));
    }
}
